# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetInstanceProfilesResult',
    'AwaitableGetInstanceProfilesResult',
    'get_instance_profiles',
    'get_instance_profiles_output',
]

@pulumi.output_type
class GetInstanceProfilesResult:
    """
    A collection of values returned by getInstanceProfiles.
    """
    def __init__(__self__, id=None, instance_profiles=None, provider_config=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_profiles and not isinstance(instance_profiles, list):
            raise TypeError("Expected argument 'instance_profiles' to be a list")
        pulumi.set(__self__, "instance_profiles", instance_profiles)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceProfiles")
    def instance_profiles(self) -> Sequence['outputs.GetInstanceProfilesInstanceProfileResult']:
        """
        Set of objects for a databricks_instance_profile. This contains the following attributes:
        """
        return pulumi.get(self, "instance_profiles")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetInstanceProfilesProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetInstanceProfilesResult(GetInstanceProfilesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceProfilesResult(
            id=self.id,
            instance_profiles=self.instance_profiles,
            provider_config=self.provider_config)


def get_instance_profiles(instance_profiles: Optional[Sequence[Union['GetInstanceProfilesInstanceProfileArgs', 'GetInstanceProfilesInstanceProfileArgsDict']]] = None,
                          provider_config: Optional[Union['GetInstanceProfilesProviderConfigArgs', 'GetInstanceProfilesProviderConfigArgsDict']] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceProfilesResult:
    """
    Lists all available databricks_instance_profiles.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Get all instance profiles:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_instance_profiles()
    pulumi.export("allInstanceProfiles", all.instance_profiles)
    ```


    :param Sequence[Union['GetInstanceProfilesInstanceProfileArgs', 'GetInstanceProfilesInstanceProfileArgsDict']] instance_profiles: Set of objects for a databricks_instance_profile. This contains the following attributes:
    :param Union['GetInstanceProfilesProviderConfigArgs', 'GetInstanceProfilesProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['instanceProfiles'] = instance_profiles
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getInstanceProfiles:getInstanceProfiles', __args__, opts=opts, typ=GetInstanceProfilesResult).value

    return AwaitableGetInstanceProfilesResult(
        id=pulumi.get(__ret__, 'id'),
        instance_profiles=pulumi.get(__ret__, 'instance_profiles'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_instance_profiles_output(instance_profiles: Optional[pulumi.Input[Optional[Sequence[Union['GetInstanceProfilesInstanceProfileArgs', 'GetInstanceProfilesInstanceProfileArgsDict']]]]] = None,
                                 provider_config: Optional[pulumi.Input[Optional[Union['GetInstanceProfilesProviderConfigArgs', 'GetInstanceProfilesProviderConfigArgsDict']]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceProfilesResult]:
    """
    Lists all available databricks_instance_profiles.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Get all instance profiles:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_instance_profiles()
    pulumi.export("allInstanceProfiles", all.instance_profiles)
    ```


    :param Sequence[Union['GetInstanceProfilesInstanceProfileArgs', 'GetInstanceProfilesInstanceProfileArgsDict']] instance_profiles: Set of objects for a databricks_instance_profile. This contains the following attributes:
    :param Union['GetInstanceProfilesProviderConfigArgs', 'GetInstanceProfilesProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['instanceProfiles'] = instance_profiles
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getInstanceProfiles:getInstanceProfiles', __args__, opts=opts, typ=GetInstanceProfilesResult)
    return __ret__.apply(lambda __response__: GetInstanceProfilesResult(
        id=pulumi.get(__response__, 'id'),
        instance_profiles=pulumi.get(__response__, 'instance_profiles'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DataClassificationCatalogConfigArgs', 'DataClassificationCatalogConfig']

@pulumi.input_type
class DataClassificationCatalogConfigArgs:
    def __init__(__self__, *,
                 parent: pulumi.Input[_builtins.str],
                 auto_tag_configs: Optional[pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]]] = None,
                 included_schemas: Optional[pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs']] = None,
                 provider_config: Optional[pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a DataClassificationCatalogConfig resource.
        :param pulumi.Input[_builtins.str] parent: Parent resource in the format: catalogs/{catalog_name}
        :param pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]] auto_tag_configs: List of auto-tagging configurations for this catalog.
               Empty list means no auto-tagging is enabled
        :param pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs'] included_schemas: Schemas to include in the scan. Empty list is not supported as it results in a no-op
               scan. If `included_schemas` is not set, all schemas are scanned
        :param pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        pulumi.set(__self__, "parent", parent)
        if auto_tag_configs is not None:
            pulumi.set(__self__, "auto_tag_configs", auto_tag_configs)
        if included_schemas is not None:
            pulumi.set(__self__, "included_schemas", included_schemas)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Input[_builtins.str]:
        """
        Parent resource in the format: catalogs/{catalog_name}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="autoTagConfigs")
    def auto_tag_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]]]:
        """
        List of auto-tagging configurations for this catalog.
        Empty list means no auto-tagging is enabled
        """
        return pulumi.get(self, "auto_tag_configs")

    @auto_tag_configs.setter
    def auto_tag_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]]]):
        pulumi.set(self, "auto_tag_configs", value)

    @_builtins.property
    @pulumi.getter(name="includedSchemas")
    def included_schemas(self) -> Optional[pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs']]:
        """
        Schemas to include in the scan. Empty list is not supported as it results in a no-op
        scan. If `included_schemas` is not set, all schemas are scanned
        """
        return pulumi.get(self, "included_schemas")

    @included_schemas.setter
    def included_schemas(self, value: Optional[pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs']]):
        pulumi.set(self, "included_schemas", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _DataClassificationCatalogConfigState:
    def __init__(__self__, *,
                 auto_tag_configs: Optional[pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]]] = None,
                 included_schemas: Optional[pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs']] = None):
        """
        Input properties used for looking up and filtering DataClassificationCatalogConfig resources.
        :param pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]] auto_tag_configs: List of auto-tagging configurations for this catalog.
               Empty list means no auto-tagging is enabled
        :param pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs'] included_schemas: Schemas to include in the scan. Empty list is not supported as it results in a no-op
               scan. If `included_schemas` is not set, all schemas are scanned
        :param pulumi.Input[_builtins.str] name: (string) - Resource name in the format: catalogs/{catalog_name}/config
        :param pulumi.Input[_builtins.str] parent: Parent resource in the format: catalogs/{catalog_name}
        :param pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        if auto_tag_configs is not None:
            pulumi.set(__self__, "auto_tag_configs", auto_tag_configs)
        if included_schemas is not None:
            pulumi.set(__self__, "included_schemas", included_schemas)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="autoTagConfigs")
    def auto_tag_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]]]:
        """
        List of auto-tagging configurations for this catalog.
        Empty list means no auto-tagging is enabled
        """
        return pulumi.get(self, "auto_tag_configs")

    @auto_tag_configs.setter
    def auto_tag_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DataClassificationCatalogConfigAutoTagConfigArgs']]]]):
        pulumi.set(self, "auto_tag_configs", value)

    @_builtins.property
    @pulumi.getter(name="includedSchemas")
    def included_schemas(self) -> Optional[pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs']]:
        """
        Schemas to include in the scan. Empty list is not supported as it results in a no-op
        scan. If `included_schemas` is not set, all schemas are scanned
        """
        return pulumi.get(self, "included_schemas")

    @included_schemas.setter
    def included_schemas(self, value: Optional[pulumi.Input['DataClassificationCatalogConfigIncludedSchemasArgs']]):
        pulumi.set(self, "included_schemas", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Resource name in the format: catalogs/{catalog_name}/config
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent resource in the format: catalogs/{catalog_name}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DataClassificationCatalogConfigProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.type_token("databricks:index/dataClassificationCatalogConfig:DataClassificationCatalogConfig")
class DataClassificationCatalogConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_tag_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DataClassificationCatalogConfigAutoTagConfigArgs', 'DataClassificationCatalogConfigAutoTagConfigArgsDict']]]]] = None,
                 included_schemas: Optional[pulumi.Input[Union['DataClassificationCatalogConfigIncludedSchemasArgs', 'DataClassificationCatalogConfigIncludedSchemasArgsDict']]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DataClassificationCatalogConfigProviderConfigArgs', 'DataClassificationCatalogConfigProviderConfigArgsDict']]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        This resource allows you to manage the Data Classification configuration for Unity Catalog catalogs.

        Data Classification automatically identifies and tags sensitive data (personally identifiable information, or PII) in Unity Catalog tables. Creating this resource enables Data Classification for the specified catalog, while deleting it disables Data Classification.

        To manage Data Classification configuration, you must either:
        1. be an owner of the catalog, OR
        2. have **USE_CATALOG** and **MANAGE** permissions on the catalog

        > **Note** This resource can only be used with a workspace-level provider.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        # Enable Data Classification for a set of schemas in a catalog
        example = databricks.DataClassificationCatalogConfig("example",
            name="catalogs/prod_catalog/config",
            included_schemas={
                "names": [
                    "sales",
                    "marketing",
                    "customer_data",
                ],
            },
            auto_tag_configs=[
                {
                    "classification_tag": "class.credit_card",
                    "auto_tagging_mode": "AUTO_TAGGING_ENABLED",
                },
                {
                    "classification_tag": "class.email",
                    "auto_tagging_mode": "AUTO_TAGGING_ENABLED",
                },
            ])
        # Enable Data Classification for the entire catalog (all current and future schemas)
        all_schemas = databricks.DataClassificationCatalogConfig("all_schemas", name="catalogs/staging_catalog/config")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DataClassificationCatalogConfigAutoTagConfigArgs', 'DataClassificationCatalogConfigAutoTagConfigArgsDict']]]] auto_tag_configs: List of auto-tagging configurations for this catalog.
               Empty list means no auto-tagging is enabled
        :param pulumi.Input[Union['DataClassificationCatalogConfigIncludedSchemasArgs', 'DataClassificationCatalogConfigIncludedSchemasArgsDict']] included_schemas: Schemas to include in the scan. Empty list is not supported as it results in a no-op
               scan. If `included_schemas` is not set, all schemas are scanned
        :param pulumi.Input[_builtins.str] parent: Parent resource in the format: catalogs/{catalog_name}
        :param pulumi.Input[Union['DataClassificationCatalogConfigProviderConfigArgs', 'DataClassificationCatalogConfigProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataClassificationCatalogConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        This resource allows you to manage the Data Classification configuration for Unity Catalog catalogs.

        Data Classification automatically identifies and tags sensitive data (personally identifiable information, or PII) in Unity Catalog tables. Creating this resource enables Data Classification for the specified catalog, while deleting it disables Data Classification.

        To manage Data Classification configuration, you must either:
        1. be an owner of the catalog, OR
        2. have **USE_CATALOG** and **MANAGE** permissions on the catalog

        > **Note** This resource can only be used with a workspace-level provider.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        # Enable Data Classification for a set of schemas in a catalog
        example = databricks.DataClassificationCatalogConfig("example",
            name="catalogs/prod_catalog/config",
            included_schemas={
                "names": [
                    "sales",
                    "marketing",
                    "customer_data",
                ],
            },
            auto_tag_configs=[
                {
                    "classification_tag": "class.credit_card",
                    "auto_tagging_mode": "AUTO_TAGGING_ENABLED",
                },
                {
                    "classification_tag": "class.email",
                    "auto_tagging_mode": "AUTO_TAGGING_ENABLED",
                },
            ])
        # Enable Data Classification for the entire catalog (all current and future schemas)
        all_schemas = databricks.DataClassificationCatalogConfig("all_schemas", name="catalogs/staging_catalog/config")
        ```

        :param str resource_name: The name of the resource.
        :param DataClassificationCatalogConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataClassificationCatalogConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_tag_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DataClassificationCatalogConfigAutoTagConfigArgs', 'DataClassificationCatalogConfigAutoTagConfigArgsDict']]]]] = None,
                 included_schemas: Optional[pulumi.Input[Union['DataClassificationCatalogConfigIncludedSchemasArgs', 'DataClassificationCatalogConfigIncludedSchemasArgsDict']]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DataClassificationCatalogConfigProviderConfigArgs', 'DataClassificationCatalogConfigProviderConfigArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataClassificationCatalogConfigArgs.__new__(DataClassificationCatalogConfigArgs)

            __props__.__dict__["auto_tag_configs"] = auto_tag_configs
            __props__.__dict__["included_schemas"] = included_schemas
            if parent is None and not opts.urn:
                raise TypeError("Missing required property 'parent'")
            __props__.__dict__["parent"] = parent
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["name"] = None
        super(DataClassificationCatalogConfig, __self__).__init__(
            'databricks:index/dataClassificationCatalogConfig:DataClassificationCatalogConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_tag_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DataClassificationCatalogConfigAutoTagConfigArgs', 'DataClassificationCatalogConfigAutoTagConfigArgsDict']]]]] = None,
            included_schemas: Optional[pulumi.Input[Union['DataClassificationCatalogConfigIncludedSchemasArgs', 'DataClassificationCatalogConfigIncludedSchemasArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['DataClassificationCatalogConfigProviderConfigArgs', 'DataClassificationCatalogConfigProviderConfigArgsDict']]] = None) -> 'DataClassificationCatalogConfig':
        """
        Get an existing DataClassificationCatalogConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DataClassificationCatalogConfigAutoTagConfigArgs', 'DataClassificationCatalogConfigAutoTagConfigArgsDict']]]] auto_tag_configs: List of auto-tagging configurations for this catalog.
               Empty list means no auto-tagging is enabled
        :param pulumi.Input[Union['DataClassificationCatalogConfigIncludedSchemasArgs', 'DataClassificationCatalogConfigIncludedSchemasArgsDict']] included_schemas: Schemas to include in the scan. Empty list is not supported as it results in a no-op
               scan. If `included_schemas` is not set, all schemas are scanned
        :param pulumi.Input[_builtins.str] name: (string) - Resource name in the format: catalogs/{catalog_name}/config
        :param pulumi.Input[_builtins.str] parent: Parent resource in the format: catalogs/{catalog_name}
        :param pulumi.Input[Union['DataClassificationCatalogConfigProviderConfigArgs', 'DataClassificationCatalogConfigProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataClassificationCatalogConfigState.__new__(_DataClassificationCatalogConfigState)

        __props__.__dict__["auto_tag_configs"] = auto_tag_configs
        __props__.__dict__["included_schemas"] = included_schemas
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["provider_config"] = provider_config
        return DataClassificationCatalogConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="autoTagConfigs")
    def auto_tag_configs(self) -> pulumi.Output[Optional[Sequence['outputs.DataClassificationCatalogConfigAutoTagConfig']]]:
        """
        List of auto-tagging configurations for this catalog.
        Empty list means no auto-tagging is enabled
        """
        return pulumi.get(self, "auto_tag_configs")

    @_builtins.property
    @pulumi.getter(name="includedSchemas")
    def included_schemas(self) -> pulumi.Output[Optional['outputs.DataClassificationCatalogConfigIncludedSchemas']]:
        """
        Schemas to include in the scan. Empty list is not supported as it results in a no-op
        scan. If `included_schemas` is not set, all schemas are scanned
        """
        return pulumi.get(self, "included_schemas")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Resource name in the format: catalogs/{catalog_name}/config
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[_builtins.str]:
        """
        Parent resource in the format: catalogs/{catalog_name}
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.DataClassificationCatalogConfigProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SqlVisualizationArgs', 'SqlVisualization']

@pulumi.input_type
class SqlVisualizationArgs:
    def __init__(__self__, *,
                 options: pulumi.Input[_builtins.str],
                 query_id: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['SqlVisualizationProviderConfigArgs']] = None,
                 query_plan: Optional[pulumi.Input[_builtins.str]] = None,
                 visualization_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SqlVisualization resource.
        :param pulumi.Input['SqlVisualizationProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "options", options)
        pulumi.set(__self__, "query_id", query_id)
        pulumi.set(__self__, "type", type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if query_plan is not None:
            pulumi.set(__self__, "query_plan", query_plan)
        if visualization_id is not None:
            pulumi.set(__self__, "visualization_id", visualization_id)

    @_builtins.property
    @pulumi.getter
    def options(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter(name="queryId")
    def query_id(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "query_id")

    @query_id.setter
    def query_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "query_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['SqlVisualizationProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['SqlVisualizationProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="queryPlan")
    def query_plan(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "query_plan")

    @query_plan.setter
    def query_plan(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_plan", value)

    @_builtins.property
    @pulumi.getter(name="visualizationId")
    def visualization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "visualization_id")

    @visualization_id.setter
    def visualization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "visualization_id", value)


@pulumi.input_type
class _SqlVisualizationState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['SqlVisualizationProviderConfigArgs']] = None,
                 query_id: Optional[pulumi.Input[_builtins.str]] = None,
                 query_plan: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 visualization_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SqlVisualization resources.
        :param pulumi.Input['SqlVisualizationProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if query_id is not None:
            pulumi.set(__self__, "query_id", query_id)
        if query_plan is not None:
            pulumi.set(__self__, "query_plan", query_plan)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if visualization_id is not None:
            pulumi.set(__self__, "visualization_id", visualization_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['SqlVisualizationProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['SqlVisualizationProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="queryId")
    def query_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "query_id")

    @query_id.setter
    def query_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_id", value)

    @_builtins.property
    @pulumi.getter(name="queryPlan")
    def query_plan(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "query_plan")

    @query_plan.setter
    def query_plan(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_plan", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="visualizationId")
    def visualization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "visualization_id")

    @visualization_id.setter
    def visualization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "visualization_id", value)


@pulumi.type_token("databricks:index/sqlVisualization:SqlVisualization")
class SqlVisualization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['SqlVisualizationProviderConfigArgs', 'SqlVisualizationProviderConfigArgsDict']]] = None,
                 query_id: Optional[pulumi.Input[_builtins.str]] = None,
                 query_plan: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 visualization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        !> This resource is deprecated and will be removed in future.

        > Please switch to Dashboard to author new AI/BI dashboards using the latest tooling

        To manage [SQLA resources](https://docs.databricks.com/sql/get-started/concepts.html) you must have `databricks_sql_access` on your Group or databricks_user.

        > documentation for this resource is a work in progress.

        A visualization is always tied to a query. Every query may have one or more visualizations.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        q1v1 = databricks.SqlVisualization("q1v1",
            query_id=q1["id"],
            type="table",
            name="My Table",
            description="Some Description",
            options=json.dumps({
                "itemsPerPage": 25,
                "columns": [
                    {
                        "name": "p1",
                        "type": "string",
                        "title": "Parameter 1",
                        "displayAs": "string",
                    },
                    {
                        "name": "p2",
                        "type": "string",
                        "title": "Parameter 2",
                        "displayAs": "link",
                        "highlightLinks": True,
                    },
                ],
            }))
        ```

        ## Separating `visualization definition` from IAC configuration

        Since `options` field contains the full JSON encoded string definition of how to render a visualization for the backend API - `sql/api/visualizations`, they can get quite verbose.

        If you have lots of visualizations to declare, it might be cleaner to separate the `options` field and store them as separate `.json` files to be referenced.

        ### Example

        - directory tree

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['SqlVisualizationProviderConfigArgs', 'SqlVisualizationProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SqlVisualizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        !> This resource is deprecated and will be removed in future.

        > Please switch to Dashboard to author new AI/BI dashboards using the latest tooling

        To manage [SQLA resources](https://docs.databricks.com/sql/get-started/concepts.html) you must have `databricks_sql_access` on your Group or databricks_user.

        > documentation for this resource is a work in progress.

        A visualization is always tied to a query. Every query may have one or more visualizations.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        q1v1 = databricks.SqlVisualization("q1v1",
            query_id=q1["id"],
            type="table",
            name="My Table",
            description="Some Description",
            options=json.dumps({
                "itemsPerPage": 25,
                "columns": [
                    {
                        "name": "p1",
                        "type": "string",
                        "title": "Parameter 1",
                        "displayAs": "string",
                    },
                    {
                        "name": "p2",
                        "type": "string",
                        "title": "Parameter 2",
                        "displayAs": "link",
                        "highlightLinks": True,
                    },
                ],
            }))
        ```

        ## Separating `visualization definition` from IAC configuration

        Since `options` field contains the full JSON encoded string definition of how to render a visualization for the backend API - `sql/api/visualizations`, they can get quite verbose.

        If you have lots of visualizations to declare, it might be cleaner to separate the `options` field and store them as separate `.json` files to be referenced.

        ### Example

        - directory tree

        :param str resource_name: The name of the resource.
        :param SqlVisualizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SqlVisualizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['SqlVisualizationProviderConfigArgs', 'SqlVisualizationProviderConfigArgsDict']]] = None,
                 query_id: Optional[pulumi.Input[_builtins.str]] = None,
                 query_plan: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 visualization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SqlVisualizationArgs.__new__(SqlVisualizationArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if options is None and not opts.urn:
                raise TypeError("Missing required property 'options'")
            __props__.__dict__["options"] = options
            __props__.__dict__["provider_config"] = provider_config
            if query_id is None and not opts.urn:
                raise TypeError("Missing required property 'query_id'")
            __props__.__dict__["query_id"] = query_id
            __props__.__dict__["query_plan"] = query_plan
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["visualization_id"] = visualization_id
        super(SqlVisualization, __self__).__init__(
            'databricks:index/sqlVisualization:SqlVisualization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            options: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['SqlVisualizationProviderConfigArgs', 'SqlVisualizationProviderConfigArgsDict']]] = None,
            query_id: Optional[pulumi.Input[_builtins.str]] = None,
            query_plan: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            visualization_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'SqlVisualization':
        """
        Get an existing SqlVisualization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['SqlVisualizationProviderConfigArgs', 'SqlVisualizationProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SqlVisualizationState.__new__(_SqlVisualizationState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["options"] = options
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["query_id"] = query_id
        __props__.__dict__["query_plan"] = query_plan
        __props__.__dict__["type"] = type
        __props__.__dict__["visualization_id"] = visualization_id
        return SqlVisualization(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def options(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "options")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.SqlVisualizationProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="queryId")
    def query_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "query_id")

    @_builtins.property
    @pulumi.getter(name="queryPlan")
    def query_plan(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "query_plan")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="visualizationId")
    def visualization_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "visualization_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetQualityMonitorV2Result',
    'AwaitableGetQualityMonitorV2Result',
    'get_quality_monitor_v2',
    'get_quality_monitor_v2_output',
]

@pulumi.output_type
class GetQualityMonitorV2Result:
    """
    A collection of values returned by getQualityMonitorV2.
    """
    def __init__(__self__, anomaly_detection_config=None, id=None, object_id=None, object_type=None, provider_config=None, validity_check_configurations=None):
        if anomaly_detection_config and not isinstance(anomaly_detection_config, dict):
            raise TypeError("Expected argument 'anomaly_detection_config' to be a dict")
        pulumi.set(__self__, "anomaly_detection_config", anomaly_detection_config)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if object_id and not isinstance(object_id, str):
            raise TypeError("Expected argument 'object_id' to be a str")
        pulumi.set(__self__, "object_id", object_id)
        if object_type and not isinstance(object_type, str):
            raise TypeError("Expected argument 'object_type' to be a str")
        pulumi.set(__self__, "object_type", object_type)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if validity_check_configurations and not isinstance(validity_check_configurations, list):
            raise TypeError("Expected argument 'validity_check_configurations' to be a list")
        pulumi.set(__self__, "validity_check_configurations", validity_check_configurations)

    @_builtins.property
    @pulumi.getter(name="anomalyDetectionConfig")
    def anomaly_detection_config(self) -> 'outputs.GetQualityMonitorV2AnomalyDetectionConfigResult':
        """
        (AnomalyDetectionConfig)
        """
        return pulumi.get(self, "anomaly_detection_config")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> _builtins.str:
        """
        (string) - The uuid of the request object. For example, schema id
        """
        return pulumi.get(self, "object_id")

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> _builtins.str:
        """
        (string) - The type of the monitored object. Can be one of the following: schema
        """
        return pulumi.get(self, "object_type")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetQualityMonitorV2ProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="validityCheckConfigurations")
    def validity_check_configurations(self) -> Sequence['outputs.GetQualityMonitorV2ValidityCheckConfigurationResult']:
        """
        (list of ValidityCheckConfiguration) - Validity check configurations for anomaly detection
        """
        return pulumi.get(self, "validity_check_configurations")


class AwaitableGetQualityMonitorV2Result(GetQualityMonitorV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQualityMonitorV2Result(
            anomaly_detection_config=self.anomaly_detection_config,
            id=self.id,
            object_id=self.object_id,
            object_type=self.object_type,
            provider_config=self.provider_config,
            validity_check_configurations=self.validity_check_configurations)


def get_quality_monitor_v2(object_id: Optional[_builtins.str] = None,
                           object_type: Optional[_builtins.str] = None,
                           provider_config: Optional[Union['GetQualityMonitorV2ProviderConfigArgs', 'GetQualityMonitorV2ProviderConfigArgsDict']] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetQualityMonitorV2Result:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    > **Deprecated** This data source is deprecated. Please use `DataQualityMonitor` instead.

    This data source can be used to fetch a quality monitors v2.

    > **Note** This data source can only be used with an workspace-level provider!

    ## Example Usage

    > **Deprecated** This data source is deprecated. Please use `DataQualityMonitor` instead.

    Referring to a quality monitor by uc object type (currently only support `schema`) and object id:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_schema(name="my_catalog.my_schema")
    this_get_quality_monitor_v2 = databricks.get_quality_monitor_v2(object_type="schema",
        object_id=this.schema_info.schema_id)
    ```


    :param _builtins.str object_id: The uuid of the request object. For example, schema id
    :param _builtins.str object_type: The type of the monitored object. Can be one of the following: schema
    :param Union['GetQualityMonitorV2ProviderConfigArgs', 'GetQualityMonitorV2ProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['objectId'] = object_id
    __args__['objectType'] = object_type
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getQualityMonitorV2:getQualityMonitorV2', __args__, opts=opts, typ=GetQualityMonitorV2Result).value

    return AwaitableGetQualityMonitorV2Result(
        anomaly_detection_config=pulumi.get(__ret__, 'anomaly_detection_config'),
        id=pulumi.get(__ret__, 'id'),
        object_id=pulumi.get(__ret__, 'object_id'),
        object_type=pulumi.get(__ret__, 'object_type'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        validity_check_configurations=pulumi.get(__ret__, 'validity_check_configurations'))
def get_quality_monitor_v2_output(object_id: Optional[pulumi.Input[_builtins.str]] = None,
                                  object_type: Optional[pulumi.Input[_builtins.str]] = None,
                                  provider_config: Optional[pulumi.Input[Optional[Union['GetQualityMonitorV2ProviderConfigArgs', 'GetQualityMonitorV2ProviderConfigArgsDict']]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetQualityMonitorV2Result]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    > **Deprecated** This data source is deprecated. Please use `DataQualityMonitor` instead.

    This data source can be used to fetch a quality monitors v2.

    > **Note** This data source can only be used with an workspace-level provider!

    ## Example Usage

    > **Deprecated** This data source is deprecated. Please use `DataQualityMonitor` instead.

    Referring to a quality monitor by uc object type (currently only support `schema`) and object id:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_schema(name="my_catalog.my_schema")
    this_get_quality_monitor_v2 = databricks.get_quality_monitor_v2(object_type="schema",
        object_id=this.schema_info.schema_id)
    ```


    :param _builtins.str object_id: The uuid of the request object. For example, schema id
    :param _builtins.str object_type: The type of the monitored object. Can be one of the following: schema
    :param Union['GetQualityMonitorV2ProviderConfigArgs', 'GetQualityMonitorV2ProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['objectId'] = object_id
    __args__['objectType'] = object_type
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getQualityMonitorV2:getQualityMonitorV2', __args__, opts=opts, typ=GetQualityMonitorV2Result)
    return __ret__.apply(lambda __response__: GetQualityMonitorV2Result(
        anomaly_detection_config=pulumi.get(__response__, 'anomaly_detection_config'),
        id=pulumi.get(__response__, 'id'),
        object_id=pulumi.get(__response__, 'object_id'),
        object_type=pulumi.get(__response__, 'object_type'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        validity_check_configurations=pulumi.get(__response__, 'validity_check_configurations')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NotificationDestinationArgs', 'NotificationDestination']

@pulumi.input_type
class NotificationDestinationArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 config: Optional[pulumi.Input['NotificationDestinationConfigArgs']] = None,
                 destination_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['NotificationDestinationProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a NotificationDestination resource.
        :param pulumi.Input[_builtins.str] display_name: The display name of the Notification Destination.
        :param pulumi.Input['NotificationDestinationConfigArgs'] config: The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        :param pulumi.Input[_builtins.str] destination_type: the type of Notification Destination.
        :param pulumi.Input['NotificationDestinationProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "display_name", display_name)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if destination_type is not None:
            pulumi.set(__self__, "destination_type", destination_type)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of the Notification Destination.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['NotificationDestinationConfigArgs']]:
        """
        The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['NotificationDestinationConfigArgs']]):
        pulumi.set(self, "config", value)

    @_builtins.property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the type of Notification Destination.
        """
        return pulumi.get(self, "destination_type")

    @destination_type.setter
    def destination_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_type", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['NotificationDestinationProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['NotificationDestinationProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _NotificationDestinationState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input['NotificationDestinationConfigArgs']] = None,
                 destination_type: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['NotificationDestinationProviderConfigArgs']] = None):
        """
        Input properties used for looking up and filtering NotificationDestination resources.
        :param pulumi.Input['NotificationDestinationConfigArgs'] config: The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        :param pulumi.Input[_builtins.str] destination_type: the type of Notification Destination.
        :param pulumi.Input[_builtins.str] display_name: The display name of the Notification Destination.
        :param pulumi.Input['NotificationDestinationProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if destination_type is not None:
            pulumi.set(__self__, "destination_type", destination_type)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['NotificationDestinationConfigArgs']]:
        """
        The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['NotificationDestinationConfigArgs']]):
        pulumi.set(self, "config", value)

    @_builtins.property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the type of Notification Destination.
        """
        return pulumi.get(self, "destination_type")

    @destination_type.setter
    def destination_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_type", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the Notification Destination.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['NotificationDestinationProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['NotificationDestinationProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.type_token("databricks:index/notificationDestination:NotificationDestination")
class NotificationDestination(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Union['NotificationDestinationConfigArgs', 'NotificationDestinationConfigArgsDict']]] = None,
                 destination_type: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['NotificationDestinationProviderConfigArgs', 'NotificationDestinationProviderConfigArgsDict']]] = None,
                 __props__=None):
        """
        This resource allows you to manage [Notification Destinations](https://docs.databricks.com/api/workspace/notificationdestinations). Notification destinations are used to send notifications for query alerts and jobs to destinations outside of Databricks. Only workspace admins can create, update, and delete notification destinations.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        `Email` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "email": {
                    "addresses": ["abc@gmail.com"],
                },
            })
        ```
        `Slack` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "slack": {
                    "url": "https://hooks.slack.com/services/...",
                },
            })
        ```
        `PagerDuty` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "pagerduty": {
                    "integration_key": "xxxxxx",
                },
            })
        ```
        `Microsoft Teams` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "microsoft_teams": {
                    "url": "https://outlook.office.com/webhook/...",
                },
            })
        ```
        `Generic Webhook` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "generic_webhook": {
                    "url": "https://example.com/webhook",
                    "username": "username",
                    "password": "password",
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['NotificationDestinationConfigArgs', 'NotificationDestinationConfigArgsDict']] config: The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        :param pulumi.Input[_builtins.str] destination_type: the type of Notification Destination.
        :param pulumi.Input[_builtins.str] display_name: The display name of the Notification Destination.
        :param pulumi.Input[Union['NotificationDestinationProviderConfigArgs', 'NotificationDestinationProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NotificationDestinationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage [Notification Destinations](https://docs.databricks.com/api/workspace/notificationdestinations). Notification destinations are used to send notifications for query alerts and jobs to destinations outside of Databricks. Only workspace admins can create, update, and delete notification destinations.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        `Email` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "email": {
                    "addresses": ["abc@gmail.com"],
                },
            })
        ```
        `Slack` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "slack": {
                    "url": "https://hooks.slack.com/services/...",
                },
            })
        ```
        `PagerDuty` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "pagerduty": {
                    "integration_key": "xxxxxx",
                },
            })
        ```
        `Microsoft Teams` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "microsoft_teams": {
                    "url": "https://outlook.office.com/webhook/...",
                },
            })
        ```
        `Generic Webhook` notification destination:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        ndresource = databricks.NotificationDestination("ndresource",
            display_name="Notification Destination",
            config={
                "generic_webhook": {
                    "url": "https://example.com/webhook",
                    "username": "username",
                    "password": "password",
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param NotificationDestinationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NotificationDestinationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Union['NotificationDestinationConfigArgs', 'NotificationDestinationConfigArgsDict']]] = None,
                 destination_type: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['NotificationDestinationProviderConfigArgs', 'NotificationDestinationProviderConfigArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NotificationDestinationArgs.__new__(NotificationDestinationArgs)

            __props__.__dict__["config"] = config
            __props__.__dict__["destination_type"] = destination_type
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["provider_config"] = provider_config
        super(NotificationDestination, __self__).__init__(
            'databricks:index/notificationDestination:NotificationDestination',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[Union['NotificationDestinationConfigArgs', 'NotificationDestinationConfigArgsDict']]] = None,
            destination_type: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['NotificationDestinationProviderConfigArgs', 'NotificationDestinationProviderConfigArgsDict']]] = None) -> 'NotificationDestination':
        """
        Get an existing NotificationDestination resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['NotificationDestinationConfigArgs', 'NotificationDestinationConfigArgsDict']] config: The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        :param pulumi.Input[_builtins.str] destination_type: the type of Notification Destination.
        :param pulumi.Input[_builtins.str] display_name: The display name of the Notification Destination.
        :param pulumi.Input[Union['NotificationDestinationProviderConfigArgs', 'NotificationDestinationProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NotificationDestinationState.__new__(_NotificationDestinationState)

        __props__.__dict__["config"] = config
        __props__.__dict__["destination_type"] = destination_type
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["provider_config"] = provider_config
        return NotificationDestination(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def config(self) -> pulumi.Output[Optional['outputs.NotificationDestinationConfig']]:
        """
        The configuration of the Notification Destination. It must contain exactly one of the following blocks:
        """
        return pulumi.get(self, "config")

    @_builtins.property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> pulumi.Output[_builtins.str]:
        """
        the type of Notification Destination.
        """
        return pulumi.get(self, "destination_type")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of the Notification Destination.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.NotificationDestinationProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .access_control_rule_set import *
from .account_federation_policy import *
from .account_network_policy import *
from .account_setting_user_preference_v2 import *
from .account_setting_v2 import *
from .aibi_dashboard_embedding_access_policy_setting import *
from .aibi_dashboard_embedding_approved_domains_setting import *
from .alert import *
from .alert_v2 import *
from .app import *
from .app_space import *
from .apps_settings_custom_template import *
from .artifact_allowlist import *
from .automatic_cluster_update_workspace_setting import *
from .budget import *
from .budget_policy import *
from .catalog import *
from .catalog_workspace_binding import *
from .cluster import *
from .cluster_policy import *
from .compliance_security_profile_workspace_setting import *
from .connection import *
from .credential import *
from .custom_app_integration import *
from .dashboard import *
from .data_classification_catalog_config import *
from .data_quality_monitor import *
from .data_quality_refresh import *
from .database_database_catalog import *
from .database_instance import *
from .database_synced_database_table import *
from .dbfs_file import *
from .default_namespace_setting import *
from .directory import *
from .disable_legacy_access_setting import *
from .disable_legacy_dbfs_setting import *
from .disable_legacy_features_setting import *
from .endpoint import *
from .enhanced_security_monitoring_workspace_setting import *
from .entitlements import *
from .entity_tag_assignment import *
from .external_location import *
from .external_metadata import *
from .feature_engineering_feature import *
from .feature_engineering_kafka_config import *
from .feature_engineering_materialized_feature import *
from .file import *
from .get_account_federation_policies import *
from .get_account_federation_policy import *
from .get_account_network_policies import *
from .get_account_network_policy import *
from .get_account_setting_user_preference_v2 import *
from .get_account_setting_v2 import *
from .get_alert_v2 import *
from .get_alerts_v2 import *
from .get_app import *
from .get_app_space import *
from .get_app_spaces import *
from .get_apps import *
from .get_apps_settings_custom_template import *
from .get_apps_settings_custom_templates import *
from .get_aws_assume_role_policy import *
from .get_aws_bucket_policy import *
from .get_aws_cross_account_policy import *
from .get_aws_unity_catalog_assume_role_policy import *
from .get_aws_unity_catalog_policy import *
from .get_budget_policies import *
from .get_budget_policy import *
from .get_catalog import *
from .get_catalogs import *
from .get_cluster import *
from .get_cluster_policy import *
from .get_clusters import *
from .get_current_config import *
from .get_current_metastore import *
from .get_current_user import *
from .get_dashboards import *
from .get_data_classification_catalog_config import *
from .get_data_quality_monitor import *
from .get_data_quality_monitors import *
from .get_data_quality_refresh import *
from .get_data_quality_refreshes import *
from .get_database_database_catalog import *
from .get_database_database_catalogs import *
from .get_database_instance import *
from .get_database_instances import *
from .get_database_synced_database_table import *
from .get_database_synced_database_tables import *
from .get_dbfs_file import *
from .get_dbfs_file_paths import *
from .get_directory import *
from .get_endpoint import *
from .get_endpoints import *
from .get_entity_tag_assignment import *
from .get_entity_tag_assignments import *
from .get_external_location import *
from .get_external_locations import *
from .get_external_metadata import *
from .get_external_metadatas import *
from .get_feature_engineering_feature import *
from .get_feature_engineering_features import *
from .get_feature_engineering_kafka_config import *
from .get_feature_engineering_kafka_configs import *
from .get_feature_engineering_materialized_feature import *
from .get_feature_engineering_materialized_features import *
from .get_functions import *
from .get_group import *
from .get_instance_pool import *
from .get_instance_profiles import *
from .get_job import *
from .get_jobs import *
from .get_knowledge_assistant import *
from .get_knowledge_assistant_knowledge_source import *
from .get_knowledge_assistant_knowledge_sources import *
from .get_knowledge_assistants import *
from .get_materialized_features_feature_tag import *
from .get_materialized_features_feature_tags import *
from .get_metastore import *
from .get_metastores import *
from .get_mlflow_experiment import *
from .get_mlflow_model import *
from .get_mlflow_models import *
from .get_mws_credentials import *
from .get_mws_network_connectivity_config import *
from .get_mws_network_connectivity_configs import *
from .get_mws_workspaces import *
from .get_node_type import *
from .get_notebook import *
from .get_notebook_paths import *
from .get_notification_destinations import *
from .get_online_store import *
from .get_online_stores import *
from .get_pipelines import *
from .get_policy_info import *
from .get_policy_infos import *
from .get_postgres_branch import *
from .get_postgres_branches import *
from .get_postgres_database import *
from .get_postgres_databases import *
from .get_postgres_endpoint import *
from .get_postgres_endpoints import *
from .get_postgres_project import *
from .get_postgres_projects import *
from .get_quality_monitor_v2 import *
from .get_quality_monitors_v2 import *
from .get_registered_model import *
from .get_registered_model_versions import *
from .get_rfa_access_request_destinations import *
from .get_schema import *
from .get_schemas import *
from .get_service_principal import *
from .get_service_principal_federation_policies import *
from .get_service_principal_federation_policy import *
from .get_service_principals import *
from .get_serving_endpoints import *
from .get_share import *
from .get_shares import *
from .get_spark_version import *
from .get_sql_warehouse import *
from .get_sql_warehouses import *
from .get_storage_credential import *
from .get_storage_credentials import *
from .get_table import *
from .get_tables import *
from .get_tag_policies import *
from .get_tag_policy import *
from .get_user import *
from .get_users import *
from .get_views import *
from .get_volume import *
from .get_volumes import *
from .get_warehouses_default_warehouse_override import *
from .get_warehouses_default_warehouse_overrides import *
from .get_workspace_entity_tag_assignment import *
from .get_workspace_entity_tag_assignments import *
from .get_workspace_network_option import *
from .get_workspace_setting_v2 import *
from .get_zones import *
from .git_credential import *
from .global_init_script import *
from .grant import *
from .grants import *
from .group import *
from .group_instance_profile import *
from .group_member import *
from .group_role import *
from .instance_pool import *
from .instance_profile import *
from .ip_access_list import *
from .job import *
from .knowledge_assistant import *
from .knowledge_assistant_knowledge_source import *
from .lakehouse_monitor import *
from .library import *
from .materialized_features_feature_tag import *
from .metastore import *
from .metastore_assignment import *
from .metastore_data_access import *
from .metastore_provider import *
from .mlflow_experiment import *
from .mlflow_model import *
from .mlflow_webhook import *
from .model_serving import *
from .model_serving_provisioned_throughput import *
from .mount import *
from .mws_credentials import *
from .mws_customer_managed_keys import *
from .mws_log_delivery import *
from .mws_ncc_binding import *
from .mws_ncc_private_endpoint_rule import *
from .mws_network_connectivity_config import *
from .mws_networks import *
from .mws_permission_assignment import *
from .mws_private_access_settings import *
from .mws_storage_configurations import *
from .mws_vpc_endpoint import *
from .mws_workspaces import *
from .notebook import *
from .notification_destination import *
from .obo_token import *
from .online_store import *
from .online_table import *
from .permission_assignment import *
from .permissions import *
from .pipeline import *
from .policy_info import *
from .postgres_branch import *
from .postgres_database import *
from .postgres_endpoint import *
from .postgres_project import *
from .provider import *
from .quality_monitor import *
from .quality_monitor_v2 import *
from .query import *
from .recipient import *
from .registered_model import *
from .repo import *
from .restrict_workspace_admins_setting import *
from .rfa_access_request_destinations import *
from .schema import *
from .secret import *
from .secret_acl import *
from .secret_scope import *
from .service_principal import *
from .service_principal_federation_policy import *
from .service_principal_role import *
from .service_principal_secret import *
from .share import *
from .sql_alert import *
from .sql_dashboard import *
from .sql_endpoint import *
from .sql_global_config import *
from .sql_permissions import *
from .sql_query import *
from .sql_table import *
from .sql_visualization import *
from .sql_widget import *
from .storage_credential import *
from .system_schema import *
from .table import *
from .tag_policy import *
from .token import *
from .user import *
from .user_instance_profile import *
from .user_role import *
from .vector_search_endpoint import *
from .vector_search_index import *
from .volume import *
from .warehouses_default_warehouse_override import *
from .workspace_binding import *
from .workspace_conf import *
from .workspace_entity_tag_assignment import *
from .workspace_file import *
from .workspace_network_option import *
from .workspace_setting_v2 import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_databricks.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_databricks.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "databricks",
  "mod": "index/accessControlRuleSet",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accessControlRuleSet:AccessControlRuleSet": "AccessControlRuleSet"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountFederationPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountFederationPolicy:AccountFederationPolicy": "AccountFederationPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountNetworkPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountNetworkPolicy:AccountNetworkPolicy": "AccountNetworkPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountSettingUserPreferenceV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountSettingUserPreferenceV2:AccountSettingUserPreferenceV2": "AccountSettingUserPreferenceV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountSettingV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountSettingV2:AccountSettingV2": "AccountSettingV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/aibiDashboardEmbeddingAccessPolicySetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/aibiDashboardEmbeddingAccessPolicySetting:AibiDashboardEmbeddingAccessPolicySetting": "AibiDashboardEmbeddingAccessPolicySetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/aibiDashboardEmbeddingApprovedDomainsSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/aibiDashboardEmbeddingApprovedDomainsSetting:AibiDashboardEmbeddingApprovedDomainsSetting": "AibiDashboardEmbeddingApprovedDomainsSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/alert",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/alertV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/alertV2:AlertV2": "AlertV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/app",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/app:App": "App"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/appSpace",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/appSpace:AppSpace": "AppSpace"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/appsSettingsCustomTemplate",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/appsSettingsCustomTemplate:AppsSettingsCustomTemplate": "AppsSettingsCustomTemplate"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/artifactAllowlist",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/artifactAllowlist:ArtifactAllowlist": "ArtifactAllowlist"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/automaticClusterUpdateWorkspaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/automaticClusterUpdateWorkspaceSetting:AutomaticClusterUpdateWorkspaceSetting": "AutomaticClusterUpdateWorkspaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/budget",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/budget:Budget": "Budget"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/budgetPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/budgetPolicy:BudgetPolicy": "BudgetPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/catalog",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/catalogWorkspaceBinding",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/catalogWorkspaceBinding:CatalogWorkspaceBinding": "CatalogWorkspaceBinding"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/cluster",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/clusterPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/clusterPolicy:ClusterPolicy": "ClusterPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/complianceSecurityProfileWorkspaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/complianceSecurityProfileWorkspaceSetting:ComplianceSecurityProfileWorkspaceSetting": "ComplianceSecurityProfileWorkspaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/connection",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/credential",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/credential:Credential": "Credential"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/customAppIntegration",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/customAppIntegration:CustomAppIntegration": "CustomAppIntegration"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dashboard",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dataClassificationCatalogConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dataClassificationCatalogConfig:DataClassificationCatalogConfig": "DataClassificationCatalogConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dataQualityMonitor",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dataQualityMonitor:DataQualityMonitor": "DataQualityMonitor"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dataQualityRefresh",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dataQualityRefresh:DataQualityRefresh": "DataQualityRefresh"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/databaseDatabaseCatalog",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/databaseDatabaseCatalog:DatabaseDatabaseCatalog": "DatabaseDatabaseCatalog"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/databaseInstance",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/databaseSyncedDatabaseTable",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/databaseSyncedDatabaseTable:DatabaseSyncedDatabaseTable": "DatabaseSyncedDatabaseTable"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dbfsFile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dbfsFile:DbfsFile": "DbfsFile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/defaultNamespaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/defaultNamespaceSetting:DefaultNamespaceSetting": "DefaultNamespaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/directory",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/disableLegacyAccessSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/disableLegacyAccessSetting:DisableLegacyAccessSetting": "DisableLegacyAccessSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/disableLegacyDbfsSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/disableLegacyDbfsSetting:DisableLegacyDbfsSetting": "DisableLegacyDbfsSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/disableLegacyFeaturesSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/disableLegacyFeaturesSetting:DisableLegacyFeaturesSetting": "DisableLegacyFeaturesSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/endpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/enhancedSecurityMonitoringWorkspaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/enhancedSecurityMonitoringWorkspaceSetting:EnhancedSecurityMonitoringWorkspaceSetting": "EnhancedSecurityMonitoringWorkspaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/entitlements",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/entitlements:Entitlements": "Entitlements"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/entityTagAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/entityTagAssignment:EntityTagAssignment": "EntityTagAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/externalLocation",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/externalLocation:ExternalLocation": "ExternalLocation"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/externalMetadata",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/externalMetadata:ExternalMetadata": "ExternalMetadata"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/featureEngineeringFeature",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/featureEngineeringFeature:FeatureEngineeringFeature": "FeatureEngineeringFeature"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/featureEngineeringKafkaConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/featureEngineeringKafkaConfig:FeatureEngineeringKafkaConfig": "FeatureEngineeringKafkaConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/featureEngineeringMaterializedFeature",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/featureEngineeringMaterializedFeature:FeatureEngineeringMaterializedFeature": "FeatureEngineeringMaterializedFeature"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/file",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/file:File": "File"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/gitCredential",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/gitCredential:GitCredential": "GitCredential"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/globalInitScript",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/globalInitScript:GlobalInitScript": "GlobalInitScript"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/grant",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/grant:Grant": "Grant"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/grants",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/grants:Grants": "Grants"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/group",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/group:Group": "Group"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/groupInstanceProfile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/groupInstanceProfile:GroupInstanceProfile": "GroupInstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/groupMember",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/groupMember:GroupMember": "GroupMember"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/groupRole",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/groupRole:GroupRole": "GroupRole"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/instancePool",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/instancePool:InstancePool": "InstancePool"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/instanceProfile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/instanceProfile:InstanceProfile": "InstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/ipAccessList",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/ipAccessList:IpAccessList": "IpAccessList"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/job",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/job:Job": "Job"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/knowledgeAssistant",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/knowledgeAssistant:KnowledgeAssistant": "KnowledgeAssistant"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/knowledgeAssistantKnowledgeSource",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/knowledgeAssistantKnowledgeSource:KnowledgeAssistantKnowledgeSource": "KnowledgeAssistantKnowledgeSource"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/lakehouseMonitor",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/lakehouseMonitor:LakehouseMonitor": "LakehouseMonitor"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/library",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/library:Library": "Library"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/materializedFeaturesFeatureTag",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/materializedFeaturesFeatureTag:MaterializedFeaturesFeatureTag": "MaterializedFeaturesFeatureTag"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastore",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastore:Metastore": "Metastore"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastoreAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastoreAssignment:MetastoreAssignment": "MetastoreAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastoreDataAccess",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastoreDataAccess:MetastoreDataAccess": "MetastoreDataAccess"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastoreProvider",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastoreProvider:MetastoreProvider": "MetastoreProvider"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mlflowExperiment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mlflowExperiment:MlflowExperiment": "MlflowExperiment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mlflowModel",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mlflowModel:MlflowModel": "MlflowModel"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mlflowWebhook",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mlflowWebhook:MlflowWebhook": "MlflowWebhook"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/modelServing",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/modelServing:ModelServing": "ModelServing"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/modelServingProvisionedThroughput",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/modelServingProvisionedThroughput:ModelServingProvisionedThroughput": "ModelServingProvisionedThroughput"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mount",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mount:Mount": "Mount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsCredentials",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsCredentials:MwsCredentials": "MwsCredentials"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsCustomerManagedKeys",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsCustomerManagedKeys:MwsCustomerManagedKeys": "MwsCustomerManagedKeys"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsLogDelivery",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsLogDelivery:MwsLogDelivery": "MwsLogDelivery"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNccBinding",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNccBinding:MwsNccBinding": "MwsNccBinding"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNccPrivateEndpointRule",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNccPrivateEndpointRule:MwsNccPrivateEndpointRule": "MwsNccPrivateEndpointRule"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNetworkConnectivityConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNetworkConnectivityConfig:MwsNetworkConnectivityConfig": "MwsNetworkConnectivityConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNetworks",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNetworks:MwsNetworks": "MwsNetworks"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsPermissionAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsPermissionAssignment:MwsPermissionAssignment": "MwsPermissionAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsPrivateAccessSettings",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsPrivateAccessSettings:MwsPrivateAccessSettings": "MwsPrivateAccessSettings"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsStorageConfigurations",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsStorageConfigurations:MwsStorageConfigurations": "MwsStorageConfigurations"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsVpcEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsVpcEndpoint:MwsVpcEndpoint": "MwsVpcEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsWorkspaces",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsWorkspaces:MwsWorkspaces": "MwsWorkspaces"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/notebook",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/notebook:Notebook": "Notebook"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/notificationDestination",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/notificationDestination:NotificationDestination": "NotificationDestination"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/oboToken",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/oboToken:OboToken": "OboToken"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/onlineStore",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/onlineStore:OnlineStore": "OnlineStore"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/onlineTable",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/onlineTable:OnlineTable": "OnlineTable"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/permissionAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/permissionAssignment:PermissionAssignment": "PermissionAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/permissions",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/permissions:Permissions": "Permissions"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/pipeline",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/policyInfo",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/policyInfo:PolicyInfo": "PolicyInfo"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresBranch",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresBranch:PostgresBranch": "PostgresBranch"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresDatabase",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresDatabase:PostgresDatabase": "PostgresDatabase"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresEndpoint:PostgresEndpoint": "PostgresEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresProject",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresProject:PostgresProject": "PostgresProject"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/qualityMonitor",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/qualityMonitor:QualityMonitor": "QualityMonitor"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/qualityMonitorV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/qualityMonitorV2:QualityMonitorV2": "QualityMonitorV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/query",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/query:Query": "Query"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/recipient",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/recipient:Recipient": "Recipient"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/registeredModel",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/registeredModel:RegisteredModel": "RegisteredModel"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/repo",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/repo:Repo": "Repo"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/restrictWorkspaceAdminsSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/restrictWorkspaceAdminsSetting:RestrictWorkspaceAdminsSetting": "RestrictWorkspaceAdminsSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/rfaAccessRequestDestinations",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/rfaAccessRequestDestinations:RfaAccessRequestDestinations": "RfaAccessRequestDestinations"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/schema",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/secret",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/secretAcl",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/secretAcl:SecretAcl": "SecretAcl"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/secretScope",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/secretScope:SecretScope": "SecretScope"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipal",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipal:ServicePrincipal": "ServicePrincipal"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipalFederationPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipalFederationPolicy:ServicePrincipalFederationPolicy": "ServicePrincipalFederationPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipalRole",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipalRole:ServicePrincipalRole": "ServicePrincipalRole"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipalSecret",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipalSecret:ServicePrincipalSecret": "ServicePrincipalSecret"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/share",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/share:Share": "Share"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlAlert",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlAlert:SqlAlert": "SqlAlert"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlDashboard",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlDashboard:SqlDashboard": "SqlDashboard"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlEndpoint:SqlEndpoint": "SqlEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlGlobalConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlGlobalConfig:SqlGlobalConfig": "SqlGlobalConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlPermissions",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlPermissions:SqlPermissions": "SqlPermissions"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlQuery",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlQuery:SqlQuery": "SqlQuery"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlTable",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlTable:SqlTable": "SqlTable"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlVisualization",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlVisualization:SqlVisualization": "SqlVisualization"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlWidget",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlWidget:SqlWidget": "SqlWidget"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/storageCredential",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/storageCredential:StorageCredential": "StorageCredential"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/systemSchema",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/systemSchema:SystemSchema": "SystemSchema"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/table",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/table:Table": "Table"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/tagPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/tagPolicy:TagPolicy": "TagPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/token",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/token:Token": "Token"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/user",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/user:User": "User"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/userInstanceProfile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/userInstanceProfile:UserInstanceProfile": "UserInstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/userRole",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/userRole:UserRole": "UserRole"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/vectorSearchEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/vectorSearchEndpoint:VectorSearchEndpoint": "VectorSearchEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/vectorSearchIndex",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/vectorSearchIndex:VectorSearchIndex": "VectorSearchIndex"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/volume",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/warehousesDefaultWarehouseOverride",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/warehousesDefaultWarehouseOverride:WarehousesDefaultWarehouseOverride": "WarehousesDefaultWarehouseOverride"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceBinding",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceBinding:WorkspaceBinding": "WorkspaceBinding"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceConf",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceConf:WorkspaceConf": "WorkspaceConf"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceEntityTagAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceEntityTagAssignment:WorkspaceEntityTagAssignment": "WorkspaceEntityTagAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceFile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceFile:WorkspaceFile": "WorkspaceFile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceNetworkOption",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceNetworkOption:WorkspaceNetworkOption": "WorkspaceNetworkOption"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceSettingV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceSettingV2:WorkspaceSettingV2": "WorkspaceSettingV2"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "databricks",
  "token": "pulumi:providers:databricks",
  "fqn": "pulumi_databricks",
  "class": "Provider"
 }
]
"""
)
